<h3>Readme</h3>

<h4>Before you get started</h4>
This code sample demonstrates the Braintree SDK for Checkout with PayPal and Hosted Fields payment experiences. 
<br />
<br />

For steps on integrating the Checkout with PayPal experience, refer to the <a href="#expresscheckout">
Checkout with PayPal integration steps</a> below. And for steps on integrating the Hosted Fields experience, refer to 
<a href="#hostedFields">Braintree Hosted Fields integration steps</a> below.

<br />
<br />

<h4>Code Sample Demonstration</h4>

<ol>
	<li>Click on the <b>Proceed to Shipping</b> button.</li>
	<li>Update the Shipping Details fields (optional).</li>
	<li>Click on the <b>Proceed to Checkout</b> button.</li>
	<li>You will land on the Checkout page.</li>
	
	<li>Select a Payment experience.
		<ul>
			<li>For the <b>Checkout with PayPal</b> experience, click on the PayPal Checkout button.
				<ol>
					<li>In the PayPal window that appears, log in with the PayPal Sandbox email and password credentials from the start page.</li>
					<li>Review the payment information and hit Continue.</li>
				</ol>
			</li>
			<li>For the <b>Hosted Fields</b> experience, enter Card Number, CVV, Expiration Date and click Pay with Card.</li>
		</ul>
	</li>
	<li>You will land on the confirmation page.</li>
</ol>	
	
	
You can try out your own <a href="https://sandbox.braintreegateway.com/login" target="_blank">Braintree Sandbox</a> 
merchant credentials by replacing the Merchant Id, Public Key and Private Key values in the <b>config.properties</b> file. 
<br />
<br />
 
 Additionally, if multiple currencies need to be handled, this needs to be mapped in <b>config.properties</b>  with the Braintree merchant accounts corresponding to each 
 currency.
 
<br />
<br />
 
For more information on accepting PayPal with Braintree, please refer to the 
<a href="https://articles.braintreepayments.com/support/guides/payment-methods/paypal/setup-guide" target="_blank">Setup Guide</a>.

<br />
<br />

<h4>Java Server-side SDK</h4>

Braintree provides an open source jar file to integrate with the Braintree Gateway on your server.  Refer to the 
<a href="https://developers.braintreepayments.com/start/hello-server/java" target="_blank">Set Up Your Server</a> page 
for the Java library download.


<br />
<br />

<h4 id="expresscheckout"> Checkout with PayPal integration steps: </h4>

<ol>
	<li>Generate a PayPal Button in the HTML.  Refer to the 'PayPal Checkout button' section of checkoutpage.jsp.</li>
	<li>Load the Braintree JavaScript components. Refer to the 'Load the Braintree JavaScript components' section of checkoutpage.jsp.</li>
	<li>Initialize the JavaScript client. Refer to the 'Load the Braintree JavaScript components' section of checkoutpage.jsp.</li>
	<li>When the PayPal Button is clicked, the form data is posted to BtCheckoutServlet (BtCheckoutServlet.java) and the transaction is processed.</li>
</ol>

Here is the basic client side script structure for Checkout with PayPal button and payment. To learn more about how to create a payment 
with Checkout with PayPal button refer <a href ="https://braintree.github.io/braintree-web/current/module-braintree-web_paypal-checkout.html#.create" target="_blank">this link</a>.<br>

<br />

<pre><code>// Be sure to have checkout.js loaded on your page.
&lt;script src=&quot;https://www.paypalobjects.com/api/checkout.js&quot; data-version-4 log-level=&quot;warn&quot;&gt;&lt;/script&gt;

braintree.paypalCheckout.create({
    client: clientInstance
    }, function (createErr, paypalCheckoutInstance) {
        if (createErr) {
            if (createErr.code === 'PAYPAL_BROWSER_NOT_SUPPORTED') {
                console.error('This browser is not supported.');
            } else {
                console.error('Error!', createErr);
            }
            return;
        }

        paypal.Button.render({
            env: 'production', // or 'sandbox'

            locale: 'en_US',

            payment: function () {
                return paypalCheckoutInstance.createPayment({
                flow: 'vault'
            });
        },

        onAuthorize: function (data, actions) {
            return paypalCheckoutInstance.tokenizePayment(data).then(function (payload) {
            // Submit payload.nonce to your server
            });
        },

        onCancel: function (data) {
            console.log('checkout.js payment cancelled', JSON.stringify(data, 0, 2));
        },

        onError: function (err) {
            console.error('checkout.js error', err);
        }
    }, '#paypal-button'); // the PayPal button will be rendered in an html element with the id `paypal-button`
});</code></pre>

<br />

<h4 id="hostedFields"> Hosted Fields integration steps: </h4>

<ol>
	<li>You can learn about the Hosted Fields 
		<a href="https://developers.braintreepayments.com/guides/hosted-fields/overview/javascript/v3" target="_blank">here</a>.
	</li>
	<li>
		Refer to the 'Hosted Fields - Pay with Card button ' section in HTML and the 'Braintree - Hosted Fields component' in 
		the JavaScript of checkoutpage.jsp  to understand how to create the Hosted Fields.
	</li>
	<li>
		When the Pay With Card button is clicked, the form data is posted to BtCheckoutServlet (BtCheckoutServlet.java) and 
		the transaction is processed.  Refer to 
		<a href ="https://developers.braintreepayments.com/reference/request/transaction/sale/java" target="_blank">
		Transaction.sale()</a> for additional information.
	</li>
</ol>

Here is the basic structure of the Hosted Fields script component. For more detailed information, please read the Braintree 
documentation for integrating <a href ="https://developers.braintreepayments.com/guides/hosted-fields/setup-and-integration/javascript/v3" target="_blank">
Hosted Fields</a>.

<br />
<br />

<pre><code>braintree.client.create({
    authorization: 'CLIENT_AUTHORIZATION'
    }, function (clientErr, clientInstance) {
        if (clientErr) {
        // Handle error in client creation
        return;
        }

        var options = {
            client: clientInstance,
            styles: {
            /* ... */
            },
            fields: {
            /* ... */
        }
    };

    braintree.hostedFields.create(options, function (hostedFieldsErr, hostedFieldsInstance) {
            if (hostedFieldsErr) {
                // Handle error in Hosted Fields creation
                return;
            }

        // Use the Hosted Fields instance here to tokenize a card
    });
});</code></pre>

